BEScrollView

Struct BEScrollView 

pub struct BEScrollView { /* private fields */ }
Available on crate feature BEScrollView only.
Implementations

Source

impl BEScrollView

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn BEScrollViewDelegate>>>

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn BEScrollViewDelegate>>, )

Setter for delegate.

This is a weak property.

Source

impl BEScrollView

Methods declared on superclass UIView.

pub unsafe fn initWithFrame( this: Allocated<Self>, frame: CGRect, ) -> Retained<Self>

Available on crate feature objc2-core-foundation only.
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Retained<Self>>

Safety

coder possibly has further requirements.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl BEScrollView

Methods declared on superclass NSObject.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = UIScrollView>

pub fn adjustedContentInsetDidChange(&self)

Available on crate features UIResponder and UIView only.
pub fn contentInsetAdjustmentBehavior( &self, ) -> UIScrollViewContentInsetAdjustmentBehavior

Available on crate features UIResponder and UIView only.
pub fn setContentInsetAdjustmentBehavior( &self, content_inset_adjustment_behavior: UIScrollViewContentInsetAdjustmentBehavior, )

Available on crate features UIResponder and UIView only.
pub fn automaticallyAdjustsScrollIndicatorInsets(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setAutomaticallyAdjustsScrollIndicatorInsets( &self, automatically_adjusts_scroll_indicator_insets: bool, )

Available on crate features UIResponder and UIView only.
pub fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn UIScrollViewDelegate>>>

Available on crate features UIResponder and UIView only.
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn UIScrollViewDelegate>>, )

Available on crate features UIResponder and UIView only.

Setter for delegate.

This is a weak property.

pub fn isDirectionalLockEnabled(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setDirectionalLockEnabled(&self, directional_lock_enabled: bool)

Available on crate features UIResponder and UIView only.
pub fn bounces(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setBounces(&self, bounces: bool)

Available on crate features UIResponder and UIView only.

Setter for bounces.

pub fn bouncesHorizontally(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setBouncesHorizontally(&self, bounces_horizontally: bool)

Available on crate features UIResponder and UIView only.

Setter for bouncesHorizontally.

pub fn bouncesVertically(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setBouncesVertically(&self, bounces_vertically: bool)

Available on crate features UIResponder and UIView only.

Setter for bouncesVertically.

pub fn alwaysBounceVertical(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setAlwaysBounceVertical(&self, always_bounce_vertical: bool)

Available on crate features UIResponder and UIView only.
pub fn alwaysBounceHorizontal(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setAlwaysBounceHorizontal(&self, always_bounce_horizontal: bool)

Available on crate features UIResponder and UIView only.
pub fn isPagingEnabled(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setPagingEnabled(&self, paging_enabled: bool)

Available on crate features UIResponder and UIView only.

Setter for isPagingEnabled.

pub fn isScrollEnabled(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setScrollEnabled(&self, scroll_enabled: bool)

Available on crate features UIResponder and UIView only.

Setter for isScrollEnabled.

pub fn transfersHorizontalScrollingToParent(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setTransfersHorizontalScrollingToParent( &self, transfers_horizontal_scrolling_to_parent: bool, )

Available on crate features UIResponder and UIView only.
pub fn transfersVerticalScrollingToParent(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setTransfersVerticalScrollingToParent( &self, transfers_vertical_scrolling_to_parent: bool, )

Available on crate features UIResponder and UIView only.
pub fn showsVerticalScrollIndicator(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setShowsVerticalScrollIndicator( &self, shows_vertical_scroll_indicator: bool, )

Available on crate features UIResponder and UIView only.
pub fn showsHorizontalScrollIndicator(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setShowsHorizontalScrollIndicator( &self, shows_horizontal_scroll_indicator: bool, )

Available on crate features UIResponder and UIView only.
pub fn indicatorStyle(&self) -> UIScrollViewIndicatorStyle

Available on crate features UIResponder and UIView only.
pub fn setIndicatorStyle(&self, indicator_style: UIScrollViewIndicatorStyle)

Available on crate features UIResponder and UIView only.

Setter for indicatorStyle.

pub fn indexDisplayMode(&self) -> UIScrollViewIndexDisplayMode

Available on crate features UIResponder and UIView only.
pub fn setIndexDisplayMode( &self, index_display_mode: UIScrollViewIndexDisplayMode, )

Available on crate features UIResponder and UIView only.

Setter for indexDisplayMode.

pub fn flashScrollIndicators(&self)

Available on crate features UIResponder and UIView only.
pub fn withScrollIndicatorsShownForContentOffsetChanges( &self, changes: &Block<dyn Fn() + '_>, )

Available on crate features block2 and UIResponder and UIView only.
pub fn topEdgeEffect(&self) -> Retained<UIScrollEdgeEffect>

Available on crate features UIResponder and UIView only.

The effect for the top edge of the scroll view.

pub fn leftEdgeEffect(&self) -> Retained<UIScrollEdgeEffect>

Available on crate features UIResponder and UIView only.

The effect for the left edge of the scroll view.

pub fn bottomEdgeEffect(&self) -> Retained<UIScrollEdgeEffect>

Available on crate features UIResponder and UIView only.

The effect for the bottom edge of the scroll view.

pub fn rightEdgeEffect(&self) -> Retained<UIScrollEdgeEffect>

Available on crate features UIResponder and UIView only.

The effect for the right edge of the scroll view.

pub fn isTracking(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn isDragging(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn isDecelerating(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn isScrollAnimating(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn delaysContentTouches(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setDelaysContentTouches(&self, delays_content_touches: bool)

Available on crate features UIResponder and UIView only.
pub fn canCancelContentTouches(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setCanCancelContentTouches(&self, can_cancel_content_touches: bool)

Available on crate features UIResponder and UIView only.
pub fn touchesShouldCancelInContentView(&self, view: &UIView) -> bool

Available on crate features UIResponder and UIView only.
pub fn bouncesZoom(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setBouncesZoom(&self, bounces_zoom: bool)

Available on crate features UIResponder and UIView only.

Setter for bouncesZoom.

pub fn isZooming(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn isZoomBouncing(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn isZoomAnimating(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn scrollsToTop(&self) -> bool

Available on crate features UIResponder and UIView only.
pub fn setScrollsToTop(&self, scrolls_to_top: bool)

Available on crate features UIResponder and UIView only.

Setter for scrollsToTop.

pub fn stopScrollingAndZooming(&self)

Available on crate features UIResponder and UIView only.
pub fn directionalPressGestureRecognizer(&self) -> Retained<UIGestureRecognizer>

👎Deprecated:

Configuring the panGestureRecognizer for indirect scrolling automatically supports directional presses now, so this property is no longer useful.

Available on crate features UIGestureRecognizer and UIResponder and UIView only.
pub fn keyboardDismissMode(&self) -> UIScrollViewKeyboardDismissMode

Available on crate features UIResponder and UIView only.
pub fn setKeyboardDismissMode( &self, keyboard_dismiss_mode: UIScrollViewKeyboardDismissMode, )

Available on crate features UIResponder and UIView only.

Setter for keyboardDismissMode.

pub fn allowsKeyboardScrolling(&self) -> bool

Available on crate features UIResponder and UIView only.

Set this to YES to make the scroll view animate its content offset in response to keys like Page Up/Down, Home/End, and the arrow keys. The scroll view must be focused or first responder in order to receive these key events. Default is YES for apps linked after iOS 17.0.

pub fn setAllowsKeyboardScrolling(&self, allows_keyboard_scrolling: bool)

Available on crate features UIResponder and UIView only.

Methods from Deref<Target = UIView>

pub fn addInteraction(&self, interaction: &ProtocolObject<dyn UIInteraction>)

Available on crate features UIResponder and UIView only.
pub fn removeInteraction(&self, interaction: &ProtocolObject<dyn UIInteraction>)

Available on crate features UIResponder and UIView only.
pub fn interactions( &self, ) -> Retained<NSArray<ProtocolObject<dyn UIInteraction>>>

Available on crate features UIResponder and UIView only.
pub fn setInteractions( &self, interactions: &NSArray<ProtocolObject<dyn UIInteraction>>, )

Available on crate features UIResponder and UIView only.

Setter for interactions.

This is copied when set.

pub fn isUserInteractionEnabled(&self) -> bool

Available on crate feature UIResponder only.
pub fn setUserInteractionEnabled(&self, user_interaction_enabled: bool)

Available on crate feature UIResponder only.
pub fn tag(&self) -> isize

Available on crate feature UIResponder only.
pub fn setTag(&self, tag: isize)

Available on crate feature UIResponder only.

Setter for tag.

pub fn canBecomeFocused(&self) -> bool

Available on crate feature UIResponder only.
pub fn isFocused(&self) -> bool

Available on crate feature UIResponder only.
pub fn focusGroupIdentifier(&self) -> Option<Retained<NSString>>

Available on crate feature UIResponder only.

The identifier of the focus group that this view belongs to. If this is nil, subviews inherit their superview’s focus group.

pub fn setFocusGroupIdentifier(&self, focus_group_identifier: Option<&NSString>)

Available on crate feature UIResponder only.

Setter for focusGroupIdentifier.

This is copied when set.

pub fn focusGroupPriority(&self) -> isize

Available on crate features UIFocus and UIResponder only.

The priority this item has in its focus group. The higher the priority, the more likely it is to get picked when focus moves into this group. Note: this method can only be used to increase an item’s priority, not decrease it. For example if an item is currently selected, the actual priority of this item will be determined by MAX(focusGroupPriority, UIFocusGroupPrioritySelected).

pub fn setFocusGroupPriority(&self, focus_group_priority: isize)

Available on crate features UIFocus and UIResponder only.

Setter for focusGroupPriority.

pub fn semanticContentAttribute(&self) -> UISemanticContentAttribute

Available on crate feature UIResponder only.
pub fn setSemanticContentAttribute( &self, semantic_content_attribute: UISemanticContentAttribute, )

Available on crate feature UIResponder only.
pub fn isMultipleTouchEnabled(&self) -> bool

Available on crate feature UIResponder only.
pub fn setMultipleTouchEnabled(&self, multiple_touch_enabled: bool)

Available on crate feature UIResponder only.
pub fn isExclusiveTouch(&self) -> bool

Available on crate feature UIResponder only.
pub fn setExclusiveTouch(&self, exclusive_touch: bool)

Available on crate feature UIResponder only.

Setter for isExclusiveTouch.

pub fn autoresizesSubviews(&self) -> bool

Available on crate feature UIResponder only.
pub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)

Available on crate feature UIResponder only.

Setter for autoresizesSubviews.

pub fn autoresizingMask(&self) -> UIViewAutoresizing

Available on crate feature UIResponder only.
pub fn setAutoresizingMask(&self, autoresizing_mask: UIViewAutoresizing)

Available on crate feature UIResponder only.

Setter for autoresizingMask.

pub fn sizeToFit(&self)

Available on crate feature UIResponder only.
pub fn superview(&self) -> Option<Retained<UIView>>

Available on crate feature UIResponder only.
pub fn subviews(&self) -> Retained<NSArray<UIView>>

Available on crate feature UIResponder only.
pub fn removeFromSuperview(&self)

Available on crate feature UIResponder only.
pub fn insertSubview_atIndex(&self, view: &UIView, index: isize)

Available on crate feature UIResponder only.
pub fn exchangeSubviewAtIndex_withSubviewAtIndex( &self, index1: isize, index2: isize, )

Available on crate feature UIResponder only.
pub fn addSubview(&self, view: &UIView)

Available on crate feature UIResponder only.
pub fn insertSubview_belowSubview( &self, view: &UIView, sibling_subview: &UIView, )

Available on crate feature UIResponder only.
pub fn insertSubview_aboveSubview( &self, view: &UIView, sibling_subview: &UIView, )

Available on crate feature UIResponder only.
pub fn bringSubviewToFront(&self, view: &UIView)

Available on crate feature UIResponder only.
pub fn sendSubviewToBack(&self, view: &UIView)

Available on crate feature UIResponder only.
pub fn didAddSubview(&self, subview: &UIView)

Available on crate feature UIResponder only.
pub fn willRemoveSubview(&self, subview: &UIView)

Available on crate feature UIResponder only.
pub fn willMoveToSuperview(&self, new_superview: Option<&UIView>)

Available on crate feature UIResponder only.
pub fn didMoveToSuperview(&self)

Available on crate feature UIResponder only.
pub fn didMoveToWindow(&self)

Available on crate feature UIResponder only.
pub fn isDescendantOfView(&self, view: &UIView) -> bool

Available on crate feature UIResponder only.
pub fn viewWithTag(&self, tag: isize) -> Option<Retained<UIView>>

Available on crate feature UIResponder only.
pub fn setNeedsUpdateProperties(&self)

Available on crate feature UIResponder only.

Call to manually request a properties update for the view. Multiple requests may be coalesced into a single update alongside the next layout pass.

pub fn updateProperties(&self)

Available on crate feature UIResponder only.

Override point for subclasses to update properties of this view. Never call this method directly; use setNeedsUpdateProperties to schedule an update.

pub fn updatePropertiesIfNeeded(&self)

Available on crate feature UIResponder only.

Forces an immediate properties update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree.

pub fn setNeedsLayout(&self)

Available on crate feature UIResponder only.
pub fn layoutIfNeeded(&self)

Available on crate feature UIResponder only.
pub fn layoutSubviews(&self)

Available on crate feature UIResponder only.
pub fn preservesSuperviewLayoutMargins(&self) -> bool

Available on crate feature UIResponder only.
pub fn setPreservesSuperviewLayoutMargins( &self, preserves_superview_layout_margins: bool, )

Available on crate feature UIResponder only.
pub fn insetsLayoutMarginsFromSafeArea(&self) -> bool

Available on crate feature UIResponder only.
pub fn setInsetsLayoutMarginsFromSafeArea( &self, insets_layout_margins_from_safe_area: bool, )

Available on crate feature UIResponder only.
pub fn layoutMarginsDidChange(&self)

Available on crate feature UIResponder only.
pub fn safeAreaInsetsDidChange(&self)

Available on crate feature UIResponder only.
pub fn setNeedsDisplay(&self)

Available on crate feature UIResponder only.
pub fn clipsToBounds(&self) -> bool

Available on crate feature UIResponder only.
pub fn setClipsToBounds(&self, clips_to_bounds: bool)

Available on crate feature UIResponder only.

Setter for clipsToBounds.

pub fn backgroundColor(&self) -> Option<Retained<UIColor>>

Available on crate features UIColor and UIResponder only.
pub fn setBackgroundColor(&self, background_color: Option<&UIColor>)

Available on crate features UIColor and UIResponder only.

Setter for backgroundColor.

This is copied when set.

pub fn isOpaque(&self) -> bool

Available on crate feature UIResponder only.
pub fn setOpaque(&self, opaque: bool)

Available on crate feature UIResponder only.

Setter for isOpaque.

pub fn clearsContextBeforeDrawing(&self) -> bool

Available on crate feature UIResponder only.
pub fn setClearsContextBeforeDrawing(&self, clears_context_before_drawing: bool)

Available on crate feature UIResponder only.
pub fn isHidden(&self) -> bool

Available on crate feature UIResponder only.
pub fn setHidden(&self, hidden: bool)

Available on crate feature UIResponder only.

Setter for isHidden.

pub fn contentMode(&self) -> UIViewContentMode

Available on crate feature UIResponder only.
pub fn setContentMode(&self, content_mode: UIViewContentMode)

Available on crate feature UIResponder only.

Setter for contentMode.

pub fn maskView(&self) -> Option<Retained<UIView>>

Available on crate feature UIResponder only.
pub fn setMaskView(&self, mask_view: Option<&UIView>)

Available on crate feature UIResponder only.

Setter for maskView.

pub fn tintColor(&self) -> Option<Retained<UIColor>>

Available on crate features UIColor and UIResponder only.
pub unsafe fn setTintColor(&self, tint_color: Option<&UIColor>)

Available on crate features UIColor and UIResponder only.

Setter for tintColor.

Safety

tint_color might not allow None.

pub fn tintAdjustmentMode(&self) -> UIViewTintAdjustmentMode

Available on crate feature UIResponder only.
pub fn setTintAdjustmentMode( &self, tint_adjustment_mode: UIViewTintAdjustmentMode, )

Available on crate feature UIResponder only.

Setter for tintAdjustmentMode.

pub fn tintColorDidChange(&self)

Available on crate feature UIResponder only.
pub fn gestureRecognizers( &self, ) -> Option<Retained<NSArray<UIGestureRecognizer>>>

Available on crate features UIGestureRecognizer and UIResponder only.
pub fn setGestureRecognizers( &self, gesture_recognizers: Option<&NSArray<UIGestureRecognizer>>, )

Available on crate features UIGestureRecognizer and UIResponder only.

Setter for gestureRecognizers.

This is copied when set.

pub fn addGestureRecognizer(&self, gesture_recognizer: &UIGestureRecognizer)

Available on crate features UIGestureRecognizer and UIResponder only.
pub fn removeGestureRecognizer(&self, gesture_recognizer: &UIGestureRecognizer)

Available on crate features UIGestureRecognizer and UIResponder only.
pub fn gestureRecognizerShouldBegin( &self, gesture_recognizer: &UIGestureRecognizer, ) -> bool

Available on crate features UIGestureRecognizer and UIResponder only.
pub fn updateConstraintsIfNeeded(&self)

Available on crate feature UIResponder only.
pub fn updateConstraints(&self)

Available on crate feature UIResponder only.
pub fn needsUpdateConstraints(&self) -> bool

Available on crate feature UIResponder only.
pub fn setNeedsUpdateConstraints(&self)

Available on crate feature UIResponder only.
pub fn translatesAutoresizingMaskIntoConstraints(&self) -> bool

Available on crate feature UIResponder only.
pub fn setTranslatesAutoresizingMaskIntoConstraints( &self, translates_autoresizing_mask_into_constraints: bool, )

Available on crate feature UIResponder only.
pub fn viewForBaselineLayout(&self) -> Retained<UIView>

👎Deprecated:

Override -viewForFirstBaselineLayout or -viewForLastBaselineLayout as appropriate, instead

Available on crate feature UIResponder only.
pub fn viewForFirstBaselineLayout(&self) -> Retained<UIView>

Available on crate feature UIResponder only.
pub fn viewForLastBaselineLayout(&self) -> Retained<UIView>

Available on crate feature UIResponder only.
pub fn invalidateIntrinsicContentSize(&self)

Available on crate feature UIResponder only.
pub fn hasAmbiguousLayout(&self) -> bool

Available on crate feature UIResponder only.
pub fn exerciseAmbiguityInLayout(&self)

Available on crate feature UIResponder only.
pub fn restorationIdentifier(&self) -> Option<Retained<NSString>>

Available on crate feature UIResponder only.
pub fn setRestorationIdentifier( &self, restoration_identifier: Option<&NSString>, )

Available on crate feature UIResponder only.

Setter for restorationIdentifier.

This is copied when set.

pub unsafe fn encodeRestorableStateWithCoder(&self, coder: &NSCoder)

Available on crate feature UIResponder only.
Safety

coder possibly has further requirements.

pub unsafe fn decodeRestorableStateWithCoder(&self, coder: &NSCoder)

Available on crate feature UIResponder only.
Safety

coder possibly has further requirements.

pub fn snapshotViewAfterScreenUpdates( &self, after_updates: bool, ) -> Option<Retained<UIView>>

Available on crate feature UIResponder only.
pub fn appliedContentSizeCategoryLimitsDescription(&self) -> Retained<NSString>

Available on crate feature UIResponder only.

Will return a string with a log of all the superviews of this view, alongside with what content size category each view has and if that view has limits applied. This is for debugging purposes only.

pub fn traitOverrides(&self) -> Retained<ProtocolObject<dyn UITraitOverrides>>

Available on crate features UIResponder and UITraitCollection only.
pub fn updateTraitsIfNeeded(&self)

Available on crate feature UIResponder only.

Forces an immediate trait update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree. Any trait change callbacks are sent synchronously.

Methods from Deref<Target = UIResponder>

pub fn nextResponder(&self) -> Option<Retained<UIResponder>>

pub fn canBecomeFirstResponder(&self) -> bool

pub fn becomeFirstResponder(&self) -> bool

pub fn canResignFirstResponder(&self) -> bool

pub fn resignFirstResponder(&self) -> bool

pub fn isFirstResponder(&self) -> bool

pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> bool

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub fn editingInteractionConfiguration( &self, ) -> UIEditingInteractionConfiguration

pub fn inputView(&self) -> Option<Retained<UIView>>

Available on crate feature UIView only.
pub fn inputAccessoryView(&self) -> Option<Retained<UIView>>

Available on crate feature UIView only.
pub fn inputAssistantItem(&self) -> Retained<UITextInputAssistantItem>

Available on crate feature UITextInput only.

This method is for clients that wish to put buttons on the Shortcuts Bar, shown on top of the keyboard. You may modify the returned inputAssistantItem to add to or replace the existing items on the bar. Modifications made to the returned UITextInputAssistantItem are reflected automatically. This method should not be overridden. Goes up the responder chain.

pub fn textInputMode(&self) -> Option<Retained<UITextInputMode>>

Available on crate feature UITextInput only.
pub fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>

pub fn reloadInputViews(&self)

pub fn userActivity(&self) -> Option<Retained<NSUserActivity>>

pub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)

Setter for userActivity.

pub fn updateUserActivityState(&self, activity: &NSUserActivity)

pub fn restoreUserActivityState(&self, activity: &NSUserActivity)

pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}