pub unsafe trait BEAccessibilityTextMarkerSupport: NSObjectProtocol {
// Provided methods
unsafe fn accessibilityBoundsForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> CGRect
where Self: Sized + Message { ... }
unsafe fn accessibilityContentForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
unsafe fn accessibilityTextMarkerRangeForCurrentSelection(
&self,
) -> Option<Retained<BEAccessibilityTextMarkerRange>>
where Self: Sized + Message { ... }
unsafe fn accessibilityTextMarkerRange(
&self,
) -> Retained<BEAccessibilityTextMarkerRange>
where Self: Sized + Message { ... }
unsafe fn accessibilityNextTextMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityPreviousTextMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityLineEndMarkerForMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityLineStartMarkerForMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityMarkerForPoint(
&self,
point: CGPoint,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityTextMarkerForPosition(
&self,
position: NSInteger,
) -> Option<Retained<BEAccessibilityTextMarker>>
where Self: Sized + Message { ... }
unsafe fn accessibilityTextMarkerRangeForRange(
&self,
range: NSRange,
) -> Option<Retained<BEAccessibilityTextMarkerRange>>
where Self: Sized + Message { ... }
unsafe fn accessibilityRangeForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> NSRange
where Self: Sized + Message { ... }
}BEAccessibilityTextMarker only.Expand description
Implement BEAccessibilityTextMarkerSupport to support assistive technology features that rely on granular text offsets.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn accessibilityBoundsForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> CGRect
Available on crate feature objc2-core-foundation only.
unsafe fn accessibilityBoundsForTextMarkerRange( &self, range: &BEAccessibilityTextMarkerRange, ) -> CGRect
objc2-core-foundation only.The accessibility frame for a text range.
Parameter range: The text marker range.
Returns: The bounds in accessibility space of the text marker range. If the bounds cannot be determined, return CGRectZero.
Sourceunsafe fn accessibilityContentForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> Option<Retained<NSString>>
unsafe fn accessibilityContentForTextMarkerRange( &self, range: &BEAccessibilityTextMarkerRange, ) -> Option<Retained<NSString>>
The accessibility content for a text range.
Parameter range: The text marker range.
Sourceunsafe fn accessibilityTextMarkerRangeForCurrentSelection(
&self,
) -> Option<Retained<BEAccessibilityTextMarkerRange>>
unsafe fn accessibilityTextMarkerRangeForCurrentSelection( &self, ) -> Option<Retained<BEAccessibilityTextMarkerRange>>
The text marker range of the current selection. Return nil if there is none.
Sourceunsafe fn accessibilityTextMarkerRange(
&self,
) -> Retained<BEAccessibilityTextMarkerRange>
unsafe fn accessibilityTextMarkerRange( &self, ) -> Retained<BEAccessibilityTextMarkerRange>
The text marker range of the current element.
Sourceunsafe fn accessibilityNextTextMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
unsafe fn accessibilityNextTextMarker( &self, marker: &BEAccessibilityTextMarker, ) -> Option<Retained<BEAccessibilityTextMarker>>
The text marker after the marker.
Parameter marker: The text marker.
Sourceunsafe fn accessibilityPreviousTextMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
unsafe fn accessibilityPreviousTextMarker( &self, marker: &BEAccessibilityTextMarker, ) -> Option<Retained<BEAccessibilityTextMarker>>
The text marker before the marker.
Parameter marker: The text marker.
Sourceunsafe fn accessibilityLineEndMarkerForMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
unsafe fn accessibilityLineEndMarkerForMarker( &self, marker: &BEAccessibilityTextMarker, ) -> Option<Retained<BEAccessibilityTextMarker>>
The text marker representing the end-of-line position of the line pointed to by the given marker.
Parameter marker: The text marker.
Sourceunsafe fn accessibilityLineStartMarkerForMarker(
&self,
marker: &BEAccessibilityTextMarker,
) -> Option<Retained<BEAccessibilityTextMarker>>
unsafe fn accessibilityLineStartMarkerForMarker( &self, marker: &BEAccessibilityTextMarker, ) -> Option<Retained<BEAccessibilityTextMarker>>
The text marker representing the start-of-line position of the line pointed to by the given marker.
Parameter marker: The text marker.
Sourceunsafe fn accessibilityMarkerForPoint(
&self,
point: CGPoint,
) -> Option<Retained<BEAccessibilityTextMarker>>
Available on crate feature objc2-core-foundation only.
unsafe fn accessibilityMarkerForPoint( &self, point: CGPoint, ) -> Option<Retained<BEAccessibilityTextMarker>>
objc2-core-foundation only.The text marker for the specific point.
Parameter point: A point in view space.
Sourceunsafe fn accessibilityTextMarkerForPosition(
&self,
position: NSInteger,
) -> Option<Retained<BEAccessibilityTextMarker>>
unsafe fn accessibilityTextMarkerForPosition( &self, position: NSInteger, ) -> Option<Retained<BEAccessibilityTextMarker>>
The text marker given an index-based position.
Parameter position: The text position as an index.
Sourceunsafe fn accessibilityTextMarkerRangeForRange(
&self,
range: NSRange,
) -> Option<Retained<BEAccessibilityTextMarkerRange>>
unsafe fn accessibilityTextMarkerRangeForRange( &self, range: NSRange, ) -> Option<Retained<BEAccessibilityTextMarkerRange>>
The text marker range given an index-based range.
Parameter range: The text marker range as an NSRange.
Sourceunsafe fn accessibilityRangeForTextMarkerRange(
&self,
range: &BEAccessibilityTextMarkerRange,
) -> NSRange
unsafe fn accessibilityRangeForTextMarkerRange( &self, range: &BEAccessibilityTextMarkerRange, ) -> NSRange
The index-based range given a text marker range.
Parameter range: The text marker range.