BEExtendedTextInputTraits

Trait BEExtendedTextInputTraits 

pub unsafe trait BEExtendedTextInputTraits: UITextInputTraits {
    // Provided methods
    unsafe fn isSingleLineDocument(&self) -> bool
       where Self: Sized + Message { ... }
    unsafe fn isTypingAdaptationEnabled(&self) -> bool
       where Self: Sized + Message { ... }
    unsafe fn insertionPointColor(&self) -> Option<Retained<UIColor>>
       where Self: Sized + Message { ... }
    unsafe fn selectionHandleColor(&self) -> Option<Retained<UIColor>>
       where Self: Sized + Message { ... }
    unsafe fn selectionHighlightColor(&self) -> Option<Retained<UIColor>>
       where Self: Sized + Message { ... }
}
Available on crate feature BETextInput only.
Provided Methods

unsafe fn isSingleLineDocument(&self) -> bool
where Self: Sized + Message,

Represents whether the active web input field is a single line document

unsafe fn isTypingAdaptationEnabled(&self) -> bool
where Self: Sized + Message,

Disables the learning of new words and corrections and prevents their addition into the keyboard lexicon

unsafe fn insertionPointColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message,

Customizes the color of the text cursor at the insertion point

unsafe fn selectionHandleColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message,

Customizes the color of the selection handles

unsafe fn selectionHighlightColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message,

Customizes the color of the selection highlight rect