pub unsafe trait BEExtensionProcess: NSObjectProtocol {
// Provided method
unsafe fn invalidate(&self)
where Self: Sized + Message { ... }
}Available on crate feature
BEExtensionProcess only.Expand description
Provided Methods
Sourceunsafe fn invalidate(&self)
unsafe fn invalidate(&self)
Stops the extension process.
When you call this method, you tell the system your app no longer needs this extension process. If this is the last connection from the host process to the extension process, the system terminates the extension process.