BEProcessCapabilityGrant

Trait BEProcessCapabilityGrant 

pub unsafe trait BEProcessCapabilityGrant: NSObjectProtocol {
    // Provided methods
    unsafe fn invalidate(&self) -> bool
       where Self: Sized + Message { ... }
    unsafe fn isValid(&self) -> bool
       where Self: Sized + Message { ... }
}
Available on crate feature BECapability only.
An object that represents a granted capability.

See also Apple’s documentation

Provided Methods

unsafe fn invalidate(&self) -> bool
where Self: Sized + Message,

Invalidates the grant, removing the capability from the process it was granted to.

unsafe fn isValid(&self) -> bool
where Self: Sized + Message,

YES if the process has been granted the capability and the grant is still valid.