pub unsafe trait BEResponderEditActions: UIResponderStandardEditActions {
// Provided methods
unsafe fn share(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn addShortcut(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn lookup(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn findSelected(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn promptForReplace(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn replace(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn translate(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
unsafe fn transliterateChinese(&self, sender: Option<&AnyObject>)
where Self: Sized + Message { ... }
}BETextInput only.Expand description
Provided Methods
Shares the selected content. See corresponding share methods in BETextInteraction.
Safety
sender should be of the correct type.
Sourceunsafe fn addShortcut(&self, sender: Option<&AnyObject>)
unsafe fn addShortcut(&self, sender: Option<&AnyObject>)
Adds a text replacement shortcut to the keyboard dictionary. See corresponding shortcut methods in BETextInteraction.
Safety
sender should be of the correct type.
Sourceunsafe fn lookup(&self, sender: Option<&AnyObject>)
unsafe fn lookup(&self, sender: Option<&AnyObject>)
Presents a dictionary definition for the selected content. See corresponding dictionary methods in BETextInteraction.
Safety
sender should be of the correct type.
Sourceunsafe fn findSelected(&self, sender: Option<&AnyObject>)
unsafe fn findSelected(&self, sender: Option<&AnyObject>)
Performs a find for the selected content See find related methods in UIResponderStandardEditActions
Safety
sender should be of the correct type.
Sourceunsafe fn promptForReplace(&self, sender: Option<&AnyObject>)
unsafe fn promptForReplace(&self, sender: Option<&AnyObject>)
Shows the replacements for the selected content. See corresponding replacement methods in BETextInteraction.
Safety
sender should be of the correct type.
Sourceunsafe fn replace(&self, sender: Option<&AnyObject>)
unsafe fn replace(&self, sender: Option<&AnyObject>)
Inserts the selected replacement for the selected content. See corresponding replacement methods in BETextInputDelegate
Safety
sender should be of the correct type.