pub unsafe trait BETextInteractionDelegate {
// Provided methods
unsafe fn systemWillChangeSelectionForInteraction(
&self,
text_interaction: &BETextInteraction,
)
where Self: Sized + Message { ... }
unsafe fn systemDidChangeSelectionForInteraction(
&self,
text_interaction: &BETextInteraction,
)
where Self: Sized + Message { ... }
}Available on crate feature
BETextInteractionDelegate only.Expand description
Provided Methods
Sourceunsafe fn systemWillChangeSelectionForInteraction(
&self,
text_interaction: &BETextInteraction,
)
Available on crate feature BETextInteraction only.
unsafe fn systemWillChangeSelectionForInteraction( &self, text_interaction: &BETextInteraction, )
BETextInteraction only.Invoked by the system when the selection is about to change in the document.
Sourceunsafe fn systemDidChangeSelectionForInteraction(
&self,
text_interaction: &BETextInteraction,
)
Available on crate feature BETextInteraction only.
unsafe fn systemDidChangeSelectionForInteraction( &self, text_interaction: &BETextInteraction, )
BETextInteraction only.Invoked by the system when the selection is about to change in the document.