BETextSelectionDirectionNavigation

Trait BETextSelectionDirectionNavigation 

pub unsafe trait BETextSelectionDirectionNavigation {
    // Provided methods
    unsafe fn moveInLayoutDirection(&self, direction: UITextLayoutDirection)
       where Self: Sized + Message { ... }
    unsafe fn extendInLayoutDirection(&self, direction: UITextLayoutDirection)
       where Self: Sized + Message { ... }
    unsafe fn moveInStorageDirection_byGranularity(
        &self,
        direction: UITextStorageDirection,
        granularity: UITextGranularity,
    )
       where Self: Sized + Message { ... }
    unsafe fn extendInStorageDirection_byGranularity(
        &self,
        direction: UITextStorageDirection,
        granularity: UITextGranularity,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature BETextInput only.
Provided Methods

unsafe fn moveInLayoutDirection(&self, direction: UITextLayoutDirection)
where Self: Sized + Message,

Moves the cursor in the specified directions, such as in response to an arrow key press.

unsafe fn extendInLayoutDirection(&self, direction: UITextLayoutDirection)
where Self: Sized + Message,

Extends text selection in the specified directions, such as in response to an arrow key press while shift is held.

unsafe fn moveInStorageDirection_byGranularity( &self, direction: UITextStorageDirection, granularity: UITextGranularity, )
where Self: Sized + Message,

Moves the cursor in the specified directions by granularity, in response to different key combinations:

Option + left/right = word Option + up/down = paragraph Command + left/right = line Command + up/down = document

unsafe fn extendInStorageDirection_byGranularity( &self, direction: UITextStorageDirection, granularity: UITextGranularity, )
where Self: Sized + Message,

Moves the selection in the specified directions by granularity, in response to different key combinations:

word = shift + option + left/right paragraph = shift + option + up/down line = shift + command + left/right document = shift + command + up/down