pub unsafe trait BEExtendedTextInputTraits: UITextInputTraits {
// Provided methods
unsafe fn isSingleLineDocument(&self) -> bool
where Self: Sized + Message { ... }
unsafe fn isTypingAdaptationEnabled(&self) -> bool
where Self: Sized + Message { ... }
unsafe fn insertionPointColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message { ... }
unsafe fn selectionHandleColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message { ... }
unsafe fn selectionHighlightColor(&self) -> Option<Retained<UIColor>>
where Self: Sized + Message { ... }
}Available on crate feature
BETextInput only.Expand description
Provided Methods
Sourceunsafe fn isSingleLineDocument(&self) -> bool
unsafe fn isSingleLineDocument(&self) -> bool
Represents whether the active web input field is a single line document
Sourceunsafe fn isTypingAdaptationEnabled(&self) -> bool
unsafe fn isTypingAdaptationEnabled(&self) -> bool
Disables the learning of new words and corrections and prevents their addition into the keyboard lexicon
Sourceunsafe fn insertionPointColor(&self) -> Option<Retained<UIColor>>
unsafe fn insertionPointColor(&self) -> Option<Retained<UIColor>>
Customizes the color of the text cursor at the insertion point
Sourceunsafe fn selectionHandleColor(&self) -> Option<Retained<UIColor>>
unsafe fn selectionHandleColor(&self) -> Option<Retained<UIColor>>
Customizes the color of the selection handles